//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: 19 December 1997
// Last Modified: Wed Jan 21 23:08:13 GMT-0800 1998
// Filename:      ...sig/code/base/CircularBuffer/CircularBuffer.h
// Syntax:        C++
// $Smake:        cc -Wall -g -c %b.cpp -I../../../include && rm -f %b.o
//
// Description: A Circular buffer to handle MIDI input in particular.
//

#ifndef _CIRCULARBUFFER_H_INCLUDED
#define _CIRCULARBUFFER_H_INCLUDED


template<class type>
class CircularBuffer {
   public:
                    CircularBuffer     (void);
                    CircularBuffer     (int maxElements);
                    CircularBuffer     (const CircularBuffer<type>& 
                                           anotherBuffer);
                   ~CircularBuffer     ();

      int           capacity           (void) const;
      type          extract            (void);
      int           getCount           (void) const;
      int           getSize            (void) const;
      void          insert             (const type& aMessage);
      type&         operator[]         (int index);
      type          read               (void);
      void          reset              (void);
      void          setSize            (int aSize);
      void          write              (const type& aMessage);

   protected:
      type*         buffer;
      int           size;
      int           writeIndex;
      int           readIndex;
      int           itemCount;

      void          increment          (int& index);
};


#include "CircularBuffer.cpp"



#endif  // _CIRCULARBUFFER_H_INCLUDED



