//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Wed Jan 21 22:35:31 GMT-0800 1998
// Last Modified: Thu Jan 22 23:13:54 GMT-0800 1998
// Last Modified: Sat Nov  7 16:09:18 PST 1998
// Filename:      ...sig/maint/code/control/MidiInPort/MidiInPort.h
// Syntax:        C++ 
//


#ifndef _MIDIINPORT_H_INCLUDED
#define _MIDIINPORT_H_INCLUDED


#include "MidiMessage.h"

#ifdef VISUAL
   #define MIDIINPORT  MidiInPort_visual
   #include "MidiInPort_visual.h"
#elif defined(LINUX)
   #define MIDIINPORT  MidiInPort_linux
   #include "MidiInPort_linux.h"
#else
   #define MIDIINPORT  MidiInPort_unsupported
   #include "MidiInPort_unsupported.h"
#endif


class MidiInPort : protected MIDIINPORT {
   public:
                  MidiInPort         (void) : MIDIINPORT() {}
                  MidiInPort         (int aPort, int autoOpen = 1) : 
                                        MIDIINPORT(aPort, autoOpen) {}
                 ~MidiInPort()       { }

      void        close(void)        { MIDIINPORT::close(); }
      void        closeAll(void)     { MIDIINPORT::closeAll(); }
      MidiMessage extract(void)      { return MIDIINPORT::extract(); }
      int         getBufferSize(void) { return MIDIINPORT::getBufferSize(); }
      int         getChannelOffset(void) const { 
                                        return MIDIINPORT::getChannelOffset(); }
      int         getCount(void)     { return MIDIINPORT::getCount(); }
      const char* getName(void)      { return MIDIINPORT::getName(); }
      static const char* getName(int i)  { return MIDIINPORT::getName(i); }
      static int         getNumPorts(void) { 
                     return MIDIINPORT::getNumPorts(); }
      int         getPort(void)      { return MIDIINPORT::getPort(); }
      int         getPortStatus(void){ 
                     return MIDIINPORT::getPortStatus(); }
      int         getTrace(void)     { return MIDIINPORT::getTrace(); }
      void        insert(const MidiMessage& aMessage) {
                     MIDIINPORT::insert(aMessage); }
      int         open(void)         { return MIDIINPORT::open(); }
      MidiMessage& operator[](int index) {
                     return MIDIINPORT::message(index); }
      void        pause(void)        { MIDIINPORT::pause(); }
      void        setBufferSize(int aSize) {
                     MIDIINPORT::setBufferSize(aSize); }
      void        setChannelOffset(int anOffset) { 
                     MIDIINPORT::setChannelOffset(anOffset); }
      void        setAndOpenPort(int aPort) { setPort(aPort); open(); }
      void        setPort(int aPort) { MIDIINPORT::setPort(aPort); }
      int         setTrace(int aState) { 
                     return MIDIINPORT::setTrace(aState); }
      void        toggleTrace(void) { MIDIINPORT::toggleTrace(); }
      void        unpause(void)      { MIDIINPORT::unpause(); }
};



#endif  // _MIDIINPORT_H_INCLUDED



